==> mdqc_1.6.0.zip: mdqc/doc/mdqcvignette.R <==
###################################################
### chunk number 1: 
###################################################
library(mdqc)
data(allQC)
dim(allQC)
allQC[1:2,]


###################################################
### chunk number 2: 
###################################################
mdout <- mdqc(allQC, method="nogroups") 
plot(mdout) 
print(mdout)
summary(mdout)


###################################################
### chunk number 3: 
###################################################
plot(mdout)


###################################################
### chunk number 4: 
###################################################
mdout <- mdqc(allQC, method="apriori",
              groups=list(1:5, 6:9, 10:11))
plot(mdout) 


###################################################
### chunk number 5: 
###################################################
plot(mdout)


###################################################
### chunk number 6: 
###################################################
mdout <- mdqc(allQC, method="cluster", k=3)
plot(mdout) 
print(mdout)


###################################################
### chunk number 7: 
###################################################
plot(mdout)


###################################################
### chunk number 8: 
###################################################
mdout <- mdqc(allQC, method="loading", k=3, pc=4)
plot(mdout)
print(mdout)


###################################################
### chunk number 9: 
###################################################
mdout <- mdqc(allQC, method="global", pc=4)
plot(mdout) 


###################################################
### chunk number 10: 
###################################################
plot(mdout)

==> mdqc_1.12.1.zip: mdqc/doc/mdqcvignette.R <==
###################################################
### chunk number 1: 
###################################################
#line 85 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
library(mdqc)
data(allQC)
dim(allQC)
allQC[1:2,]


###################################################
### chunk number 2: 
###################################################
#line 97 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="nogroups") 
plot(mdout) 
print(mdout)
summary(mdout)


###################################################
### chunk number 3: 
###################################################
#line 106 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
plot(mdout)


###################################################
### chunk number 4: 
###################################################
#line 145 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="apriori",
              groups=list(1:5, 6:9, 10:11))
plot(mdout) 


###################################################
### chunk number 5: 
###################################################
#line 153 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
plot(mdout)


###################################################
### chunk number 6: 
###################################################
#line 204 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="cluster", k=3)
plot(mdout) 
print(mdout)


###################################################
### chunk number 7: 
###################################################
#line 212 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
plot(mdout)


###################################################
### chunk number 8: 
###################################################
#line 232 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="loading", k=3, pc=4)
plot(mdout)
print(mdout)


###################################################
### chunk number 9: 
###################################################
#line 254 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
mdout <- mdqc(allQC, method="global", pc=4)
plot(mdout) 


###################################################
### chunk number 10: 
###################################################
#line 261 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpZsgOmI/R.INSTALL5e4f5a5/mdqc/inst/doc/mdqcvignette.Rnw"
plot(mdout)
